#mkdir temp
#cd temp
#../scripts/checkstyle.sh
log_file1="checkpatch.log"
log_file2="formatpatch.log"
cp ../*.c ./
cp ../*.h ./
cp ../Makefile ./
cp ../scripts/.clang-format ./
chmod +w *
md5sum * > md5.txt
echo "Run checkpatch"
mv vcmdregistertable.h vcmdregistertable.hxx
../scripts/checkpatch.pl --strict --no-tree -f *.c *.h Makefile > $log_file1 
mv vcmdregistertable.hxx vcmdregistertable.h
# vcmdregistertable.h has some long string.
../scripts/checkpatch.pl --strict --no-tree --max-line-length=120 -f vcmdregistertable.h >> $log_file1 
error_num=`grep 'ERROR:' $log_file1 | wc | awk '{print $1}'`
warning_num=`grep 'WARNING:' $log_file1 | wc | awk '{print $1}'`
warning_ver=`grep 'WARNING: LINUX_VERSION_CODE' $log_file1 | awk '{sum+=1} END {print sum}'`
warning_len=`grep 'WARNING: line over 80 characters' $log_file1 | awk '{sum+=1} END {print sum}'`
warning_spdx=`grep 'WARNING: Missing or malformed SPDX-License-Identifier tag' $log_file1 | awk '{sum+=1} END {print sum}'`
warning_align=`grep 'WARNING: Block comments should align' $log_file1 | awk '{sum+=1} END {print sum}'`
check_num=`grep 'CHECK:' $log_file1 | wc | awk '{print $1}'`
check_case=`grep 'CHECK: Avoid CamelCase' $log_file1 | awk '{sum+=1} END {print sum}'`
echo "==== checkpatch result summary ===="
echo "Total number of ERROR   : $error_num"
echo "Total number of WARNING : $warning_num"
echo "       for VERSION CODE - $warning_ver (ignore)"
echo "       for Line Length  - $warning_len"
echo "       for alignment    - $warning_align"
echo "  WARNINGs treat as ERROR (NEED FIX)"
echo "       for SPDX-License - $warning_spdx"
echo "Total number of CHECK   : $check_num"
echo "       for CamelCase    - $check_case"
echo "==================================="

echo "Run clang-format and then checkpatch to fix in-place"
clang-format-6.0 -assume-filename=$PWD/.clang-format -i *.h --verbose > /dev/null 2>&1
clang-format-6.0 -assume-filename=$PWD/.clang-format -i *.c --verbose > /dev/null 2>&1
dos2unix * > /dev/null 2>&1
mv vcmdregistertable.h vcmdregistertable.hxx
../scripts/checkpatch.pl --strict --no-tree --fix-inplace -f *.c *.h Makefile > $log_file2 
mv vcmdregistertable.hxx vcmdregistertable.h
# vcmdregistertable.h has some long string.
../scripts/checkpatch.pl --strict --no-tree --fix-inplace --max-line-length=120 -f vcmdregistertable.h >> $log_file2 

md5sum -c md5.txt

